==> driza-0.6.0.tar.gz: driza-0.6/Driza/dialogs/dimportartexto.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#Dialogo de importacion de texto


#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#pushButton1: Boton aceptar
#pushButton2: Cancelar
#pushButton3: Boton de inclusion de funciones en caja de texto
#pushButton4 Inclusión de variable en caja de texto
#textEdit1: Caja de escritura
#listbox1: listado de variables
#listbox2: listado categoria funciones
#listbox3: listado funciones
#lineEdit1: Caja con el nombre de la variable
#lineEdit2: Caja con la descripción
#comboBox1: Caja con el tipo


from Driza.ui.dialogos.importartexto import DialogoImportarTexto
from qt import *


class DImportarTexto(DialogoImportarTexto):
	"""Dialogo de creación de variables, permite obtener nuevas variables a partir de las ya existentes"""

	def __init__(self,parent,gestorficheros):
		"""Inicialización"""
		DialogoImportarTexto.__init__(self,parent,"dialogo importar texto",0,0)
		self.archivo=None
		self.__gestorfichero=gestorficheros
		self.__conexiones()
	#FUNCIONES PUBLICAS		

	def accept(self):
		if not self.archivo:
			QErrorMessage(self,"error").message(u"No ha escogido el archivo")
		else:
			if self.comboBox1.currentText()=="Intro":
				delreg="\n"
			else:
				delreg=";"
			if self.comboBox2.currentText()=="Espacio":
				delatr=" "
			elif self.comboBox2.currentText()=="Dos puntos":
				delatr=":"
			else:
				delatr="\t"
			if self.checkBox1.isChecked():
				cabecera=True
			else: cabecera=False
			try:
				self.__gestorfichero.importartexto(self.archivo,delimitadorreg=delreg,delimitadoratrib=delatr,cabeceras=cabecera)
			except:
				print "Error en la importacion (TODO)"
			DialogoImportarTexto.accept(self)
			self.parent().show()


	#FUNCIONES PRIVADAS
	def __conexiones(self):
		"""Bloque de conexiones"""
		self.connect(self.pushButton1,SIGNAL("clicked()"),self.__seleccionarfichero)
		self.connect(self.pushButton2,SIGNAL("clicked()"),self.accept)
		self.connect(self.pushButton3,SIGNAL("clicked()"),self.reject)

	def __seleccionarfichero(self):
		import string
		filter="%s files (*.%s);;" % ("Txt",string.lower("Txt"))
		self.archivo=str(QFileDialog.getOpenFileName(QString.null,filter,self,None,"importar fichero",""))

==> driza-0.6.1.tar.gz: driza-0.6.1/Driza/dialogs/dimportartexto.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#Dialogo de importacion de texto


#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#pushButton1: Boton aceptar
#pushButton2: Cancelar
#pushButton3: Boton de inclusion de funciones en caja de texto
#pushButton4 Inclusión de variable en caja de texto
#textEdit1: Caja de escritura
#listbox1: listado de variables
#listbox2: listado categoria funciones
#listbox3: listado funciones
#lineEdit1: Caja con el nombre de la variable
#lineEdit2: Caja con la descripción
#comboBox1: Caja con el tipo


from Driza.ui.dialogos.importartexto import DialogoImportarTexto
from qt import *


class DImportarTexto(DialogoImportarTexto):
	"""Dialogo de creación de variables, permite obtener nuevas variables a partir de las ya existentes"""

	def __init__(self,parent,gestorficheros):
		"""Inicialización"""
		DialogoImportarTexto.__init__(self,parent,"dialogo importar texto",0,0)
		self.archivo=None
		self.__gestorfichero=gestorficheros
		self.__conexiones()
	#FUNCIONES PUBLICAS		

	def accept(self):
		if not self.archivo:
			QErrorMessage(self,"error").message(u"No ha escogido el archivo")
		else:
			if self.comboBox1.currentText()=="Intro":
				delreg="\n"
			else:
				delreg=";"
			if self.comboBox2.currentText()=="Espacio":
				delatr=""
			elif self.comboBox2.currentText()=="Dos puntos":
				delatr=":"
			else:
				delatr="\t"
			if self.checkBox1.isChecked():
				cabecera=True
			else: cabecera=False
		#	try:
			self.__gestorfichero.importartexto(self.archivo,delimitadorreg=delreg,delimitadoratrib=delatr,cabeceras=cabecera)
		#	except:
		#		print "Error en la importacion (TODO)"
			DialogoImportarTexto.accept(self)
			self.parent().grid.show()


	#FUNCIONES PRIVADAS
	def __conexiones(self):
		"""Bloque de conexiones"""
		self.connect(self.pushButton1,SIGNAL("clicked()"),self.__seleccionarfichero)
		self.connect(self.pushButton2,SIGNAL("clicked()"),self.accept)
		self.connect(self.pushButton3,SIGNAL("clicked()"),self.reject)

	def __seleccionarfichero(self):
		import string
		filter="%s files (*.%s);;" % ("Txt",string.lower("Txt"))
		self.archivo=str(QFileDialog.getOpenFileName(QString.null,filter,self,None,"importar fichero",""))
